@@ -12,10 +12,12 @@ from yupi.graphics._stats_plots import (
     plot_msd,
     plot_vacf,
     plot_velocity_hist,
-    plot_psd
+    plot_psd,
+    plot_hist,
+    plot_hists
 )
 
-from yupi.graphics._trajs_plots import plot_2D
+from yupi.graphics._trajs_plots import plot_2D, plot_3D
 
 from yupi.graphics._style import (
     LINE,
@@ -30,7 +32,10 @@ __all__ = [
     'plot_vacf',
     'plot_velocity_hist',
     'plot_2D',
+    'plot_3D',
     'plot_psd',
+    'plot_hist',
+    'plot_hists',
     'LINE',
     'LINE_DOTTED',
     'DOTTED'
