@@ -7,6 +7,11 @@ from ``yupi.stats``.
 """
 
 from yupi.stats._stats import (
+    collect_at_step,
+    collect_at_time,
+    collect_step_lagged,
+    collect_time_lagged,
+    collect,
     turning_angles_ensemble,
     speed_ensemble,
     msd_ensemble,
@@ -22,6 +27,11 @@ from yupi.stats._stats import (
 
 __all__ = [
     'turning_angles_ensemble',
+    'collect_at_step',
+    'collect_at_time',
+    'collect_step_lagged',
+    'collect_time_lagged',
+    'collect',
     'speed_ensemble',
     'msd_ensemble',
     'msd_time',
