@@ -1,6 +1,8 @@
-from typing import List, Tuple
+from typing import Callable, List, Tuple, Any, Union
 import numpy as np
+import logging
 from yupi.trajectory import Trajectory
+from yupi.vector import Vector
 from yupi.transformations import subsample
 from yupi._checkers import (
     _check_uniform_time_spaced,
@@ -11,6 +13,249 @@ from yupi._checkers import (
 )
 
 
+def collect_at_step(trajs: List[Trajectory], step: int, warnings: bool = True,
+                    velocity: bool = False,
+                    func: Callable[[Vector], Vector] = None) -> np.ndarray:
+    """
+    Collects the positional data (or velocity) of each trajectory at a given
+    step.
+
+    Parameters
+    ----------
+    trajs : List[Trajectory]
+        List of trajectories.
+    step : int
+        Index of the collected vector of each trajectory.
+    warnings : bool
+        If True, warns if the trajectory is shorter than the step, by default
+        True.
+    velocity : bool
+        If True, the velocity of the trajectory is used, by default False.
+    func : Callable[[Vector], Vector]
+        Function to apply to the collected vector of each trajectory.
+        By default, the identity function.
+
+    Returns
+    -------
+    np.ndarray
+        Array of collected data.
+
+    See Also
+    --------
+    collect_at_time, collect_step_lagged, collect_time_lagged, collect
+    """
+    return collect(trajs, at=step, warnings=warnings, velocity=velocity, func=func)
+
+def collect_at_time(trajs: List[Trajectory], time: float, warnings: bool = True,
+                    velocity: bool = False,
+                    func: Callable[[Vector], Vector] = None) -> np.ndarray:
+    """
+    Collects the positional data (or velocity) of each trajectory at a given
+    time.
+
+    Parameters
+    ----------
+    trajs : List[Trajectory]
+        List of trajectories.
+    time : float
+        Time of the collected vector of each trajectory.
+
+        It is calculated using the trajectory's dt.
+    warnings : bool
+        If True, warns if the trajectory is shorter than the time, by default
+        True.
+    velocity : bool
+        If True, the velocity of the trajectory is used, by default False.
+    func : Callable[[Vector], Vector]
+        Function to apply to the collected vector of each trajectory.
+        By default, the identity function.
+
+    Returns
+    -------
+    np.ndarray
+        Array of collected data.
+
+    See Also
+    --------
+    collect_at_step, collect_step_lagged, collect_time_lagged, collect
+    """
+    return collect(trajs, at=time, warnings=warnings, velocity=velocity, func=func)
+
+def collect_step_lagged(trajs: List[Trajectory], step: int, warnings: bool = True,
+                        velocity: bool = False, concat: bool = True,
+                        func: Callable[[Vector], Vector] = None) -> np.ndarray:
+    """
+    Collects the positional data (or velocity) of each trajectory lagged by a
+    given step.
+
+    Parameters
+    ----------
+    trajs : List[Trajectory]
+        List of trajectories.
+    step : int
+        Number of steps to lag.
+    warnings : bool
+        If True, warns if the trajectory is shorter than the step, by default
+        True.
+    velocity : bool
+        If True, the velocity of the trajectory is used, by default False.
+    concat : bool
+        If True, the data is concatenated, by default True.
+    func : Callable[[Vector], Vector]
+        Function to apply to the collected vector of each trajectory.
+        By default, the identity function.
+
+    Returns
+    -------
+    np.ndarray
+        Array of collected data.
+
+    See Also
+    --------
+    collect_at_step, collect_at_step, collect_time_lagged, collect
+    """
+    return collect(trajs, lag=step, concat=concat, warnings=warnings,
+                   velocity=velocity, func=func)
+
+def collect_time_lagged(trajs: List[Trajectory], time: float, warnings: bool = True,
+                        velocity: bool = False, concat: bool = True,
+                        func: Callable[[Vector], Vector] = None) -> np.ndarray:
+    """
+    Collects the positional data (or velocity) of each trajectory lagged by a
+    given time.
+
+    Parameters
+    ----------
+    trajs : List[Trajectory]
+        List of trajectories.
+    time : float
+        Time to lag.
+    warnings : bool
+        If True, warns if the trajectory is shorter than the step, by default
+        True.
+    velocity : bool
+        If True, the velocity of the trajectory is used, by default False.
+    concat : bool
+        If True, the data is concatenated, by default True.
+    func : Callable[[Vector], Vector]
+        Function to apply to the collected vector of each trajectory.
+        By default, the identity function.
+
+    Returns
+    -------
+    np.ndarray
+        Array of collected data.
+
+    See Also
+    --------
+    collect_at_step, collect_at_time, collect_step_lagged, collect
+    """
+    return collect(trajs, lag=time, concat=concat, warnings=warnings,
+                   velocity=velocity, func=func)
+
+
+def collect(trajs: List[Trajectory], lag: Union[int, float] = None,
+            concat: bool = True, warnings: bool = True, velocity: bool = False,
+            func: Callable[[Vector], Any] = None,
+            at: Union[int, float] = None) -> np.ndarray:
+    """
+    Collect general function.
+
+    It can collect the data of each trajectory lagged by a given step or time
+    (step if ``lag`` is ``int``, time if ``lag`` is ``float``). It can also
+    collect the data of each trajectory at a given step or time (step if ``at``
+    is ``int``, time if ``at`` is ``float``). Both ``lag`` and ``at``
+    parameters can not be used at the same time.
+
+    Parameters
+    ----------
+    trajs : List[Trajectory]
+        Group of trajectories.
+    lag : int or float, optional
+        If int, the number of samples to lag. If float, the time to lag.
+    concat : bool, optional
+        If true each trajectory stracted data will be concatenated in
+        a single array, by default True.
+    warnings : bool, optional
+        If true, warnings will be printed if a trajectory is shorter
+        than the lag, by default True.
+    velocity : bool, optional
+        If true, the velocity will be returned (calculated using the
+        lag if given), by default False.
+    func : Callable[[Vector], Any], optional
+        Function to apply to each resulting vector, by default None.
+    at : Union[int, float], optional
+        If int, the index of the collected vector in the trajectory. If
+        float, it is taken as time and the index is calculated using
+        the trajectory's dt.
+
+    Returns
+    -------
+    np.ndarray
+        Collected data.
+
+    Raises
+    ------
+    ValueError
+        If ``lag`` and ``at`` are given at the same time.
+    """
+
+    is_step = lag is not None and isinstance(lag, int)
+    is_time = lag is not None and isinstance(lag, float)
+    is_at_step = at is not None and isinstance(at, int)
+    is_at_time = at is not None and isinstance(at, float)
+
+    if is_step + is_time + is_at_step + is_at_time == 0:
+        is_step = True
+        lag = 0
+    if is_step + is_time + is_at_step + is_at_time > 1:
+        raise ValueError("You can not set `lag` and `at` parameters at the "
+                         "same time")
+    is_lag = is_step or is_time
+    is_at = is_at_step or is_at_time
+
+
+    data = []
+
+    for traj in trajs:
+        if is_lag:
+            step = int(lag / traj.dt) if is_time else int(lag)
+        else:
+            step = int(at / traj.dt) if is_at_time else int(at)
+
+        current_vec = traj.r
+        if step == 0:
+            if velocity:
+                current_vec = traj.v
+            if func is not None:
+                current_vec = func(current_vec)
+            data.append(current_vec if is_lag else current_vec[step])
+            continue
+
+        if warnings and step >= len(current_vec):
+            logging.warning(f"Trajectory {traj.traj_id} is shorten than "
+                            f"{step} samples")
+            continue
+
+        if is_at:
+            data.append(current_vec[step])
+            continue
+
+        lagged_vec = current_vec[step:] - current_vec[:-step]
+        if velocity:
+            lagged_vec /= traj.dt * step
+
+        if func is not None:
+            lagged_vec = func(lagged_vec)
+
+        data.append(lagged_vec)
+    
+    if concat and is_lag:
+        return np.concatenate(data)
+    equal_len = np.all(len(d) == len(data[0]) for d in data)
+    return np.array(data) if equal_len else np.array(data, dtype=object)
+
+
 @_check_same_dt
 @_check_exact_dim(2)
 @_check_uniform_time_spaced
@@ -498,7 +743,7 @@ def kurtosis(trajs: List[Trajectory], time_avg: bool = True,
 def kurtosis_reference(trajs: List[Trajectory]) -> float:
     """Get the sampled kurtosis for the case of
     ``len(trajs)`` trajectories whose position
-    vectors are normaly distributed.
+    vectors are normally distributed.
 
     Parameters
     ----------
@@ -545,7 +790,7 @@ def psd(trajs: List[Trajectory], lag: int, omega: bool = False) -> np.ndarray:
     """
 
     _vacf = vacf_time(trajs, lag)
-    ft = np.fft.fft(_vacf, axis=0)
+    ft = np.fft.fft(_vacf, axis=0) * trajs[0].dt
     ft = np.fft.fftshift(ft)
     ft_abs = np.abs(ft)
     ft_mean = np.mean(ft_abs, axis=1)
