@@ -3,14 +3,15 @@ import json
 import csv
 import os
 from pathlib import Path
-from typing import List, NamedTuple, Union
+from typing import List, NamedTuple, Tuple, Union
 import numpy as np
 
 from yupi.vector import Vector
 from yupi.exceptions import LoadTrajectoryError
+from yupi.features import Features
 
 
-_threshold = 1e-14
+_threshold = 1e-12
 
 
 class TrajectoryPoint(NamedTuple):
@@ -183,6 +184,8 @@ class Trajectory():
                 raise ValueError("You are giving 'dt' and 't' but 't0' is not "
                                  "the same as the first value of 't'.")
 
+        self.features = Features(self)
+
     @property
     def uniformly_spaced(self) -> bool:
         """bool : True if the time data is uniformly spaced"""
@@ -237,6 +240,17 @@ class Trajectory():
         for i in range(len(self)):
             yield self[i]
 
+    @property
+    def bounds(self) -> List[Tuple[float]]:
+        """List[Tuple[float]] : List of tuples indicanting the min and
+        max values of each dimension"""
+        _bounds = []
+        for d in range(self.dim):
+            min_bound = min(self.r.component(d))
+            max_bound = max(self.r.component(d))
+            _bounds.append((min_bound, max_bound))
+        return _bounds
+
     @property
     def dim(self) -> int:
         """int : Trajectory spacial dimensions."""
@@ -248,6 +262,12 @@ class Trajectory():
         in the Trajectory."""
         return self.r.delta
 
+    @property
+    def delta_v(self) -> Vector:
+        """Vector: Difference between each couple of consecutive sample
+        in the velocity vector of the Trajectory."""
+        return self.v.delta
+
     @property
     def delta_ang(self) -> Union[Vector, None]:
         """Union[Vector, None] : Difference between each couple of
@@ -524,7 +544,7 @@ class Trajectory():
             ang_shape = 0 if self.ang is None else self.ang.shape[1]
             writer.writerow([self.traj_id, self.dt, self.dim, ang_shape])
             for tp in self:
-                row = np.hstack(np.array([tp.r, tp.ang, tp.t]))
+                row = np.hstack(np.array([tp.r, tp.ang, tp.t], dtype=object))
                 writer.writerow(row)
 
     def save(self, file_name: str, path: str = '.', file_type: str = 'json',
